@@ -1188,12 +1188,12 @@ def plot_esn_predictions(esn,y_pred,style_dict,modes=None,phase='test'):
                      y_gt[:,imode], 
                      label = 'GT',
                      color = clrs[0],
-                     linewidth = linewidth)
+                     linewidth = lw)
         axs[ii].plot(range(nt),
                      y_pred[:,imode], 
                      label = 'ESN',linestyle="dashed",
                      color = clrs[1],
-                     linewidth = linewidth)
+                     linewidth = lw)
 
 
         axs[ii].set_ylabel(ylabels[ii], fontsize = fs_label, rotation = 0, labelpad = 17)
@@ -1201,8 +1201,8 @@ def plot_esn_predictions(esn,y_pred,style_dict,modes=None,phase='test'):
 
     # tidy up
     for iax in axs:
-        iax.tick_params(axis="x", labelsize = fs_ticks)
-        iax.tick_params(axis="y", labelsize = fs_ticks)
+        iax.tick_params(axis="x", labelsize = fs_tick)
+        iax.tick_params(axis="y", labelsize = fs_tick)
 
     axs[-1].set_xlabel('time step',fontsize = fs_label);
 
